@@ -28,14 +28,14 @@ from cornflow.commands import (
     register_dag_permissions_command,
 )
 from cornflow.config import app_config
-from cornflow.endpoints import resources
+from cornflow.endpoints import resources, alarms_resources
 from cornflow.endpoints.login import LoginEndpoint, LoginOpenAuthEndpoint
 from cornflow.endpoints.signup import SignUpEndpoint
+from cornflow.shared import db, bcrypt
+from cornflow.shared.compress import init_compress
 from cornflow.shared.const import AUTH_DB, AUTH_LDAP, AUTH_OID
+from cornflow.shared.exceptions import initialize_errorhandlers
 from cornflow.shared.log_config import log_config
-from cornflow_core.compress import init_compress
-from cornflow_core.exceptions import initialize_errorhandlers
-from cornflow_core.shared import db, bcrypt
 
 
 def create_app(env_name="development", dataconn=None):
@@ -49,6 +49,7 @@ def create_app(env_name="development", dataconn=None):
     dictConfig(log_config(app_config[env_name].LOG_LEVEL))
 
     app = Flask(__name__)
+    app.json.sort_keys = False
     app.logger.setLevel(app_config[env_name].LOG_LEVEL)
 
     app.config.from_object(app_config[env_name])
@@ -73,10 +74,16 @@ def create_app(env_name="development", dataconn=None):
     api = Api(app)
     for res in resources:
         api.add_resource(res["resource"], res["urls"], endpoint=res["endpoint"])
+    if app.config["ALARMS_ENDPOINTS"]:
+        for res in alarms_resources:
+            api.add_resource(res["resource"], res["urls"], endpoint=res["endpoint"])
 
     docs = FlaskApiSpec(app)
     for res in resources:
         docs.register(target=res["resource"], endpoint=res["endpoint"])
+    if app.config["ALARMS_ENDPOINTS"]:
+        for res in alarms_resources:
+            docs.register(target=res["resource"], endpoint=res["endpoint"])
 
     # Resource for the log-in
     auth_type = app.config["AUTH_TYPE"]
