@@ -2,17 +2,19 @@ import configparser
 import os
 
 from click.testing import CliRunner
+from flask_testing import TestCase
+
 from cornflow.app import create_app
 from cornflow.cli import cli
-from cornflow.models import UserModel
-from cornflow_core.models import (
-    ActionBaseModel,
-    RoleBaseModel,
-    ViewBaseModel,
-    PermissionViewRoleBaseModel,
+from cornflow.models import (
+    ActionModel,
+    RoleModel,
+    ViewModel,
+    PermissionViewRoleModel,
 )
-from cornflow_core.shared import db
-from flask_testing import TestCase
+from cornflow.models import UserModel
+from cornflow.shared import db
+from cornflow.shared.exceptions import NoPermission, ObjectDoesNotExist
 
 
 class CLITests(TestCase):
@@ -62,7 +64,7 @@ class CLITests(TestCase):
         runner = CliRunner()
         result = runner.invoke(cli, ["actions", "init", "-v"])
         self.assertEqual(result.exit_code, 0)
-        actions = ActionBaseModel.get_all_objects().all()
+        actions = ActionModel.get_all_objects().all()
         self.assertEqual(len(actions), 5)
 
     def test_config_entrypoint(self):
@@ -113,7 +115,7 @@ class CLITests(TestCase):
         runner = CliRunner()
         result = runner.invoke(cli, ["roles", "init", "-v"])
         self.assertEqual(result.exit_code, 0)
-        roles = RoleBaseModel.get_all_objects().all()
+        roles = RoleModel.get_all_objects().all()
         self.assertEqual(len(roles), 4)
 
     def test_views_entrypoint(self):
@@ -128,8 +130,8 @@ class CLITests(TestCase):
         runner = CliRunner()
         result = runner.invoke(cli, ["views", "init", "-v"])
         self.assertEqual(result.exit_code, 0)
-        views = ViewBaseModel.get_all_objects().all()
-        self.assertEqual(len(views), 44)
+        views = ViewModel.get_all_objects().all()
+        self.assertEqual(len(views), 49)
 
     def test_permissions_entrypoint(self):
         runner = CliRunner()
@@ -147,14 +149,14 @@ class CLITests(TestCase):
         runner = CliRunner()
         result = runner.invoke(cli, ["permissions", "init", "-v"])
         self.assertEqual(result.exit_code, 0)
-        actions = ActionBaseModel.get_all_objects().all()
-        roles = RoleBaseModel.get_all_objects().all()
-        views = ViewBaseModel.get_all_objects().all()
-        permissions = PermissionViewRoleBaseModel.get_all_objects().all()
+        actions = ActionModel.get_all_objects().all()
+        roles = RoleModel.get_all_objects().all()
+        views = ViewModel.get_all_objects().all()
+        permissions = PermissionViewRoleModel.get_all_objects().all()
         self.assertEqual(len(actions), 5)
         self.assertEqual(len(roles), 4)
-        self.assertEqual(len(views), 44)
-        self.assertEqual(len(permissions), 488)
+        self.assertEqual(len(views), 49)
+        self.assertEqual(len(permissions), 546)
 
     def test_permissions_base_command(self):
         runner = CliRunner()
@@ -163,14 +165,14 @@ class CLITests(TestCase):
         runner.invoke(cli, ["views", "init", "-v"])
         result = runner.invoke(cli, ["permissions", "base", "-v"])
         self.assertEqual(result.exit_code, 0)
-        actions = ActionBaseModel.get_all_objects().all()
-        roles = RoleBaseModel.get_all_objects().all()
-        views = ViewBaseModel.get_all_objects().all()
-        permissions = PermissionViewRoleBaseModel.get_all_objects().all()
+        actions = ActionModel.get_all_objects().all()
+        roles = RoleModel.get_all_objects().all()
+        views = ViewModel.get_all_objects().all()
+        permissions = PermissionViewRoleModel.get_all_objects().all()
         self.assertEqual(len(actions), 5)
         self.assertEqual(len(roles), 4)
-        self.assertEqual(len(views), 44)
-        self.assertEqual(len(permissions), 488)
+        self.assertEqual(len(views), 49)
+        self.assertEqual(len(permissions), 546)
 
     def test_service_entrypoint(self):
         runner = CliRunner()
@@ -208,6 +210,7 @@ class CLITests(TestCase):
 
     def test_service_user_command(self):
         runner = CliRunner()
+        self.test_roles_init_command()
         result = runner.invoke(
             cli,
             [
@@ -222,7 +225,144 @@ class CLITests(TestCase):
                 "test@test.org",
             ],
         )
-        self.assertEqual(result.exit_code, 1)
+        self.assertEqual(result.exit_code, 0)
         user = UserModel.get_one_user_by_email("test@test.org")
         self.assertEqual(user.username, "test")
         self.assertEqual(user.email, "test@test.org")
+        self.assertEqual(user.roles, {4: "service"})
+        self.assertTrue(user.is_service_user())
+
+    def test_viewer_user_command(self):
+        runner = CliRunner()
+        self.test_roles_init_command()
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "viewer",
+                "-u",
+                "test",
+                "-p",
+                "testPassword1!",
+                "-e",
+                "test@test.org",
+            ],
+        )
+
+        self.assertEqual(result.exit_code, 0)
+        user = UserModel.get_one_user_by_email("test@test.org")
+        self.assertEqual(user.username, "test")
+        self.assertEqual(user.email, "test@test.org")
+        self.assertEqual(user.roles, {1: "viewer"})
+        self.assertFalse(user.is_service_user())
+
+    def test_generate_token(self):
+        runner = CliRunner()
+
+        self.test_roles_init_command()
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "viewer",
+                "-u",
+                "viewer_user",
+                "-p",
+                "testPassword1!",
+                "-e",
+                "viewer@test.org",
+            ],
+        )
+
+        self.assertEqual(result.exit_code, 0)
+
+        user_id = UserModel.get_one_user_by_username("viewer_user").id
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "service",
+                "-u",
+                "test",
+                "-p",
+                "testPassword1!",
+                "-e",
+                "test@test.org",
+            ],
+        )
+
+        self.assertEqual(result.exit_code, 0)
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "token",
+                "-i",
+                user_id,
+                "-u",
+                "test",
+                "-p",
+                "testPassword1!",
+            ],
+        )
+
+        self.assertIn("ey", result.output)
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "token",
+                "-i",
+                user_id,
+                "-u",
+                "test",
+                "-p",
+                "Otherpassword",
+            ],
+        )
+
+        self.assertEqual(result.exit_code, 1)
+        self.assertIsInstance(result.exception, NoPermission)
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "token",
+                "-i",
+                user_id,
+                "-u",
+                "viewer_user",
+                "-p",
+                "testPassword1!",
+            ],
+        )
+
+        self.assertIsInstance(result.exception, NoPermission)
+
+        result = runner.invoke(
+            cli,
+            [
+                "users",
+                "create",
+                "token",
+                "-i",
+                100,
+                "-u",
+                "test",
+                "-p",
+                "testPassword1!",
+            ],
+        )
+
+        self.assertIsInstance(result.exception, ObjectDoesNotExist)
